#Crotal

[![downloads](https://img.shields.io/pypi/dm/crotal.svg)](https://pypi.python.org/pypi/crotal/)
[![version](https://img.shields.io/pypi/v/crotal.svg)](https://pypi.python.org/pypi/crotal/)
[![supported](https://img.shields.io/pypi/pyversions/crotal.svg)](https://pypi.python.org/pypi/crotal/)
![license](https://img.shields.io/pypi/l/crotal.svg)

A static site framework. Fast, powerful, and easy as 1, 2, 3.

Homepage: [crotal.org](http://crotal.org)

PyPI: [pypi.python.org/pypi/crotal](https://pypi.python.org/pypi/crotal)

##Installation

via pip:

    $ (sudo) pip install crotal

via github:

    $ git clone https://github.com/dinever/crotal.git
    $ cd crotal
    $ (sudo) python setup.py install

##Usage

    $ crotal init my_site && cd my_site
    $ crotal generate
    $ crotal server

Now the website is available at http://localhost:1124.

##Documents

See [Crotal.org](http://crotal.org/docs).

##License

[GPL Licenses](https://github.com/dinever/crotal/blob/master/LICENSE)


[![Bitdeli Badge](https://d2weczhvl823v0.cloudfront.net/dinever/crotal/trend.png)](https://bitdeli.com/free "Bitdeli Badge")
